@@ -23,13 +23,13 @@
  *
  * Contributor(s): ______________________________________.
  *
- * $Revision: 20385 $
+ * $Revision: 21788 $
  * $Author: rjongbloed $
- * $Date: 2008-06-04 10:40:38 +0000 (Wed, 04 Jun 2008) $
+ * $Date: 2008-12-11 23:42:13 -0600 (Thu, 11 Dec 2008) $
  */
 
-#ifndef _PHTTP_H
-#define _PHTTP_H
+#ifndef PTLIB_HTTP_H
+#define PTLIB_HTTP_H
 
 #ifdef P_USE_PRAGMA
 #pragma interface
@@ -1697,7 +1697,7 @@ class PHTTPDirRequest : public PHTTPFileRequest
 
 #endif // P_HTTP
 
-#endif // _PHTTP_H
+#endif // PTLIB_HTTP_H
 
 
 // End Of File ///////////////////////////////////////////////////////////////
