@@ -26,14 +26,14 @@
  *
  * Contributor(s): ______________________________________.
  *
- * $Revision: 20385 $
+ * $Revision: 21788 $
  * $Author: rjongbloed $
- * $Date: 2008-06-04 12:40:38 +0200 (mer 04 jun 2008) $
+ * $Date: 2008-12-11 23:42:13 -0600 (Thu, 11 Dec 2008) $
  */
 
 
-#ifndef _PFILE
-#define _PFILE
+#ifndef PTLIB_FILE_H
+#define PTLIB_FILE_H
 
 #ifdef P_USE_PRAGMA
 #pragma interface
@@ -559,6 +559,8 @@ class PFile : public PChannel
 #endif
 };
 
-#endif
+
+#endif // PTLIB_FILE_H
+
 
 // End Of File ///////////////////////////////////////////////////////////////
