@@ -23,9 +23,9 @@
  *
  * Contributor(s): ______________________________________.
  *
- * $Revision: 20385 $
+ * $Revision: 23090 $
  * $Author: rjongbloed $
- * $Date: 2008-06-04 12:40:38 +0200 (mer 04 jun 2008) $
+ * $Date: 2009-07-08 11:30:47 -0500 (Wed, 08 Jul 2009) $
  */
 
 #ifdef __GNUC__
@@ -106,8 +106,13 @@ void PBase64::ProcessEncoding(const void * dataPtr, PINDEX length)
   const BYTE * data = (const BYTE *)dataPtr;
   while (saveCount < 3) {
     saveTriple[saveCount++] = *data++;
-    if (--length == 0)
+    if (--length == 0) {
+      if (saveCount == 3) {
+        OutputBase64(saveTriple);
+        saveCount = 0;
+      }
       return;
+    }
   }
 
   OutputBase64(saveTriple);
