@@ -27,9 +27,9 @@
  *
  * Contributor(s): ______________________________________.
  *
- * $Revision: 20769 $
- * $Author: csoutheren $
- * $Date: 2008-08-30 00:00:24 +0000 (Sat, 30 Aug 2008) $
+ * $Revision: 22250 $
+ * $Author: rjongbloed $
+ * $Date: 2009-03-22 23:04:50 -0500 (Sun, 22 Mar 2009) $
  */
 
 #include <ptlib.h>
@@ -1524,7 +1524,7 @@ PBoolean PODBCRecord::IsColumnNullable( PINDEX Column )
 PBoolean PODBCRecord::IsColumnUpdatable(PINDEX Column )
 {
 
-   SWORD colUpdate=0;
+   SQLLEN colUpdate=0;
    SQLColAttribute(m_hStmt,     // StatementHandle
         (SQLSMALLINT)(Column),  // ColumnNumber
         SQL_DESC_UPDATABLE,	// FieldIdentifier
@@ -1538,7 +1538,7 @@ PBoolean PODBCRecord::IsColumnUpdatable(PINDEX Column )
 PBoolean PODBCRecord::IsColumnAutoIndex(PINDEX Column )
 {
 
-   SWORD colIndex=0;
+   SQLLEN colIndex=0;
    SQLColAttribute(m_hStmt,	// StatementHandle
         (SQLSMALLINT)(Column),  // ColumnNumber
         SQL_DESC_AUTO_UNIQUE_VALUE,  // FieldIdentifier
@@ -1551,7 +1551,7 @@ PBoolean PODBCRecord::IsColumnAutoIndex(PINDEX Column )
 
 unsigned int PODBCRecord::ColumnPrecision(PINDEX Column )
 {
-   SWORD coldigits=0;
+   SQLLEN coldigits=0;
    SQLColAttribute(m_hStmt,      // StatementHandle
         (SQLSMALLINT)(Column),   // ColumnNumber
         SQL_DESC_PRECISION,      // FieldIdentifier
