@@ -23,9 +23,9 @@
  *
  * Contributor(s): ______________________________________.
  *
- * $Revision: 20781 $
- * $Author: dsandras $
- * $Date: 2008-08-30 19:14:53 +0000 (Sat, 30 Aug 2008) $
+ * $Revision: 23120 $
+ * $Author: rjongbloed $
+ * $Date: 2009-07-21 18:31:08 -0500 (Tue, 21 Jul 2009) $
  */
 
 #ifdef __GNUC__
@@ -712,13 +712,14 @@ PBoolean PSTUNClient::CreateSocket(PUDPSocket * & socket, const PIPSocket::Addre
   socket = NULL;
 
   switch (GetNatType(PFalse)) {
+    case OpenNat :
     case ConeNat :
     case RestrictedNat :
     case PortRestrictedNat :
       break;
 
     case SymmetricNat :
-      if (singlePortInfo.basePort == 0 || singlePortInfo.basePort > singlePortInfo.maxPort)
+      if (localPort == 0 && (singlePortInfo.basePort == 0 || singlePortInfo.basePort > singlePortInfo.maxPort))
       {
         PTRACE(1, "STUN\tInvalid local UDP port range "
                << singlePortInfo.currentPort << '-' << singlePortInfo.maxPort);
@@ -785,6 +786,7 @@ PBoolean PSTUNClient::CreateSocketPair(PUDPSocket * & socket1,
   socket2 = NULL;
 
   switch (GetNatType(PFalse)) {
+    case OpenNat :
     case ConeNat :
     case RestrictedNat :
     case PortRestrictedNat :
