@@ -26,9 +26,9 @@
  *
  * Contributor(s): ______________________________________.
  *
- * $Revision: 23208 $
- * $Author: csoutheren $
- * $Date: 2009-08-12 05:24:02 +0000 (Wed, 12 Aug 2009) $
+ * $Revision: 24342 $
+ * $Author: ededu $
+ * $Date: 2010-05-14 09:27:54 -0500 (Fri, 14 May 2010) $
  */
 
 #include <ptlib.h>
@@ -67,7 +67,7 @@ class CustomAllocator
 {
   public:
     Type * Allocate(size_t n)
-    { return a.allocate(n); }
+    { return (Type*)a.allocate(n); }
 
     void Deallocate(Type * p, size_t n)
     { a.deallocate(p, n); }
@@ -77,7 +77,7 @@ class CustomAllocator
       if (new_n == old_n)
         return p;
 
-      Type * np = a.allocate(new_n);
+      Type * np = (Type *)a.allocate(new_n);
       memcpy(np, p, (new_n < old_n) ? new_n : old_n );
       a.deallocate(p, old_n); 
 
