@@ -26,9 +26,9 @@
  *
  * Contributor(s): ______________________________________.
  *
- * $Revision: 23177 $
- * $Author: rjongbloed $
- * $Date: 2009-07-29 07:46:33 +0000 (Wed, 29 Jul 2009) $
+ * $Revision: 24331 $
+ * $Author: ededu $
+ * $Date: 2010-05-07 13:36:59 -0500 (Fri, 07 May 2010) $
  */
 
 #include <ptlib.h>
@@ -1505,16 +1505,19 @@ PBoolean PIPSocket::Listen(const Address & bindAddr,
   Psockaddr bind_sa(bindAddr, port); 
 #endif
 
-  if (!IsOpen()) {
-    // attempt to create a socket
 #if P_HAS_IPV6
-    if (!OpenSocket(bind_sa->sa_family))
-      return PFalse;
+  // Always close and re-open as the bindAddr address family might change.
+  Close();
+
+  // attempt to create a socket
+  if (!OpenSocket(bind_sa->sa_family))
+    return PFalse;
 #else
+  if (!IsOpen()) {
     if (!OpenSocket())
       return PFalse;
-#endif
   }
+#endif
   
 #ifndef P_BEOS
 #if P_HAS_IPV6
