@@ -23,9 +23,9 @@
  *
  * Contributor(s): Mark Cooke (mpc@star.sr.bham.ac.uk)
  *
- * $Revision: 21747 $
- * $Author: rjongbloed $
- * $Date: 2008-12-10 02:06:07 +0000 (Wed, 10 Dec 2008) $
+ * $Revision: 24328 $
+ * $Author: ededu $
+ * $Date: 2010-05-07 11:20:51 -0500 (Fri, 07 May 2010) $
  */
 
 #ifdef __GNUC__
@@ -99,6 +99,7 @@ static struct {
   { "YUV411P", 12 },
   { "RGB565",  16 },
   { "RGB555",  16 },
+  { "RGB16",   16 },
   { "YUV410",  10 },
   { "YUV410P", 10 },
   { "Grey",     8 },
