@@ -26,9 +26,9 @@
  *
  * Contributor(s): ______________________________________.
  *
- * $Revision: 22729 $
+ * $Revision: 23336 $
  * $Author: rjongbloed $
- * $Date: 2009-05-27 01:21:12 +0000 (Wed, 27 May 2009) $
+ * $Date: 2009-09-04 20:02:14 -0500 (Fri, 04 Sep 2009) $
  */
 
 #define _CONFIG_CXX
@@ -49,7 +49,7 @@
 #define	EXTENSION		".ini"
 #define	ENVIRONMENT_CONFIG_STR	"/\~~environment~~\/"
 
-#if defined(P_MACOSX) || defined(P_SOLARIS)
+#if defined(P_MACOSX) || defined(P_SOLARIS) || defined(P_FREEBSD)
 #define environ (NULL)
 #endif
 
