@@ -26,9 +26,9 @@
  *
  * Contributor(s): ______________________________________.
  *
- * $Revision: 21519 $
+ * $Revision: 23336 $
  * $Author: rjongbloed $
- * $Date: 2008-11-14 03:23:08 +0000 (Fri, 14 Nov 2008) $
+ * $Date: 2009-09-04 20:02:14 -0500 (Fri, 04 Sep 2009) $
  */
 
 #define _OSUTIL_CXX
@@ -400,7 +400,7 @@ PString PX_GetThreadName(pthread_t id)
 {
   if (PProcessInstance != NULL) {
     PWaitAndSignal m(PProcessInstance->activeThreadMutex);
-    PThread & thread = PProcessInstance->activeThreads[(unsigned)id];
+    PThread & thread = PProcessInstance->activeThreads[_hptr(id)];
     return thread.GetThreadName();
   }
   return psprintf("%08x", id);
@@ -557,7 +557,8 @@ void PProcess::CommonConstruct()
   // Setup signal handlers
   pxSignals = 0;
 
-  SetSignals(&PXSignalHandler);
+  if (!m_library)
+    SetSignals(&PXSignalHandler);
 
 #if !defined(P_VXWORKS) && !defined(P_RTEMS)
   // initialise the timezone information
@@ -575,7 +576,9 @@ void PProcess::CommonDestruct()
   delete configFiles;
 #endif
   configFiles = NULL;
-  SetSignals(NULL);
+
+  if (!m_library)
+    SetSignals(NULL);
 }
 
 // rtems fixes
